@@ -15,8 +15,8 @@
 # specific language governing permissions and limitations
 # under the License.
 
-package Search::Elasticsearch::Client::6_0::Async::Scroll;
-$Search::Elasticsearch::Client::6_0::Async::Scroll::VERSION = '7.715';
+package Search::Elasticsearch::Client::7_0::Async::Scroll;
+$Search::Elasticsearch::Client::7_0::Async::Scroll::VERSION = '7.713';
 use Moo;
 use Search::Elasticsearch::Util qw(parse_params throw);
 use Search::Elasticsearch::Async::Util qw(thenable);
@@ -31,19 +31,15 @@ has 'on_error'      => ( is => 'lazy', clearer => '_clear_on_error' );
 has '_guard'        => ( is => 'rwp', clearer => '_clear__guard' );
 
 with 'Search::Elasticsearch::Role::Is_Async',
-    'Search::Elasticsearch::Client::6_0::Role::Scroll';
+    'Search::Elasticsearch::Client::7_0::Role::Scroll';
 
 #===================================
 sub BUILDARGS {
 #===================================
     my ( $class, $search_params ) = parse_params(@_);
 
-    throw( 'Param',
-        'The (scroll_in_body) parameter has been replaced by (scroll_in_qs)' )
-        if exists $search_params->{scroll_in_body};
-
-    my %params;
-    for (qw(es on_start on_result on_results on_error scroll_in_qs)) {
+        my %params;
+    for (qw(es on_start on_result on_results on_error)) {
         my $val = delete $search_params->{$_};
         next unless defined $val;
         $params{$_} = $val;
@@ -209,10 +205,7 @@ sub finish {
         return $d->promise;
     }
 
-    my %args
-        = $self->scroll_in_qs
-        ? ( scroll_id => $scroll_id )
-        : ( body => { scroll_id => $scroll_id } );
+    my %args = ( body => { scroll_id => $scroll_id } );
 
     $self->es->clear_scroll(%args)->then(
         sub {
@@ -236,11 +229,11 @@ __END__
 
 =head1 NAME
 
-Search::Elasticsearch::Client::6_0::Async::Scroll - A helper module for scrolled searches
+Search::Elasticsearch::Client::7_0::Async::Scroll - A helper module for scrolled searches
 
 =head1 VERSION
 
-version 7.715
+version 7.713
 
 =head1 SYNOPSIS
 
@@ -291,17 +284,17 @@ until there are no more matching results, much like a cursor in an SQL
 database.
 
 Unlike paginating through results (with the C<from> parameter in
-L<search()|Search::Elasticsearch::Client::6_0::Direct/search()>),
+L<search()|Search::Elasticsearch::Client::7_0::Direct/search()>),
 scrolled searches take a snapshot of the current state of the index. Even
 if you keep adding new documents to the index or updating existing documents,
 a scrolled search will only see the index as it was when the search began.
 
 This module is a helper utility that wraps the functionality of the
-L<search()|Search::Elasticsearch::Client::6_0::Direct/search()> and
-L<scroll()|Search::Elasticsearch::Client::6_0::Direct/scroll()> methods to make
+L<search()|Search::Elasticsearch::Client::7_0::Direct/search()> and
+L<scroll()|Search::Elasticsearch::Client::7_0::Direct/scroll()> methods to make
 them easier to use.
 
-This class does L<Search::Elasticsearch::Client::6_0::Role::Scroll> and
+This class does L<Search::Elasticsearch::Client::7_0::Role::Scroll> and
 L<Search::Elasticsearch::Role::Is_Async>.
 
 =head1 USE CASES
@@ -380,7 +373,7 @@ C<client_id>:
 
 Very often the I<something> that you will want to do with these results
 involves bulk-indexing them into a new index. The easiest way to
-do this is to use the built-in L<Search::Elasticsearch::Client::6_0::Direct/reindex()>
+do this is to use the built-in L<Search::Elasticsearch::Client::7_0::Direct/reindex()>
 functionality provided by Elasticsearch.
 
 =head1 METHODS
@@ -392,7 +385,6 @@ functionality provided by Elasticsearch.
     my $es = Search::Elasticsearch::Async->new(...);
     my $scroll = $es->scroll_helper(
         scroll             => '1m',            # optional
-        scroll_in_qs       => 0|1,             # optional
 
         on_result          => sub {...}        # required
       | on_results         => sub {...}        # required
@@ -403,14 +395,12 @@ functionality provided by Elasticsearch.
     );
     $scroll->start;
 
-The L<Search::Elasticsearch::Client::6_0::Direct/scroll_helper()> method loads
-L<Search::Elasticsearch::Client::6_0::Async::Scroll> class and calls L</new()>,
+The L<Search::Elasticsearch::Client::7_0::Direct/scroll_helper()> method loads
+L<Search::Elasticsearch::Client::7_0::Async::Scroll> class and calls L</new()>,
 passing in any arguments.
 
-You can specify a C<scroll> duration (which defaults to C<"1m">),
-C<scroll_in_qs> (which defaults to C<false>), and any
-of the listed callbacks. Any other parameters are
-passed directly to L<Search::Elasticsearch::Client::6_0::Direct/search()>.
+You can specify a C<scroll> duration (which defaults to C<"1m">).
+Any other parameters are passed directly to L<Search::Elasticsearch::Client::7_0::Direct/search()>.
 
 The C<scroll> duration tells Elasticearch how long it should keep the scroll
 alive.  B<Note>: this duration doesn't need to be long enough to process
@@ -419,10 +409,7 @@ The expiry gets renewed for another C<scroll> period every time new
 a new batch of results is retrieved from the cluster.
 
 By default, the C<scroll_id> is passed as the C<body> to the
-L<scroll|Search::Elasticsearch::Client::6_0::Direct/scroll()> request.
-To send it in the query string instead, set C<scroll_in_qs> to a true value,
-but be aware: when querying very many indices, the scroll ID can become
-too long for intervening proxies.
+L<scroll|Search::Elasticsearch::Client::7_0::Direct/scroll()> request.
 
 The C<scroll> request uses C<GET> by default.  To use C<POST> instead,
 set L<send_get_body_as|Search::Elasticsearch::Transport/send_get_body_as> to
@@ -548,9 +535,9 @@ This value can only be checked once the scroll has completed.
 
 =over
 
-=item * L<Search::Elasticsearch::Client::6_0::Direct/search()>
+=item * L<Search::Elasticsearch::Client::7_0::Direct/search()>
 
-=item * L<Search::Elasticsearch::Client::6_0::Direct/scroll()>
+=item * L<Search::Elasticsearch::Client::7_0::Direct/scroll()>
 
 =back
 
