@@ -1,3 +1,20 @@
+# Licensed to Elasticsearch B.V. under one or more contributor
+# license agreements. See the NOTICE file distributed with
+# this work for additional information regarding copyright
+# ownership. Elasticsearch B.V. licenses this file to you under
+# the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+
 #!perl -d
 use EV;
 use AE;
@@ -13,11 +30,18 @@ my $trace
     : $ENV{TRACE} eq '1' ? 'Stderr'
     :                      [ 'File', $ENV{TRACE} ];
 
-die 'No $ENV{ES_VERSION} specified' unless $ENV{ES_VERSION};
+unless ($ENV{CLIENT_VER}) {
+    plan skip_all => 'No $ENV{CLIENT_VER} specified';
+    exit;
+}
+unless ($ENV{ES}) {
+    plan skip_all => 'No Elasticsearch test node available';
+    exit;
+}
 
 my $cv = AE::cv;
 
-my $api      = "$ENV{ES_VERSION}::Direct";
+my $api      = "$ENV{CLIENT_VER}::Direct";
 my $body     = $ENV{ES_BODY} || 'GET';
 my $cxn      = $ENV{ES_CXN} || do "default_async_cxn.pl" || die( $@ || $! );
 my $cxn_pool = $ENV{ES_CXN_POOL} || 'Async::Static';
@@ -98,4 +122,3 @@ unless ( $ENV{ES_SKIP_PING} ) {
 }
 
 return $es;
-
